@@ -187,14 +187,14 @@ try:
 			# newer table version requires different lookups
 			if rs[0] == 1:
 				cursor = db.cursor()
-				sql  = "SELECT jfp.`id`, jfp.`parent`, jfp.`scope_id`, jfp.`category_id`, jfp.`title`, fc.alias, fs.alias "
+				sql  = "SELECT jfp.`id`, jfp.`parent`, jfp.`scope_id`, jfp.`category_id`, jfp.`title`, fc.alias, fs.alias, fc.closed "
 				sql += "FROM jos_forum_posts jfp "
 				sql += "JOIN jos_forum_categories fc on (fc.id = jfp.category_id) "
 				sql += "JOIN jos_forum_sections fs on (fs.id = fc.section_id) "
 				sql += "WHERE jfp.id = %s "
 			else:
 				cursor = db.cursor()
-				sql  = "SELECT jfp.`id`, jfp.`parent`, jfp.`group_id`, jfp.`category_id`, jfp.`title` "
+				sql  = "SELECT jfp.`id`, jfp.`parent`, jfp.`group_id`, jfp.`category_id`, jfp.`title`, 0 ,0"
 				sql += "FROM jos_forum_posts jfp "
 				sql += "WHERE jfp.id = %s "
 				
@@ -212,15 +212,21 @@ try:
 				posttitle = rs[4]
 				postcategory = rs[5]
 				postsection = rs[6]
+				closed = rs[7]
 
 			cursor.close()
 			db.close()
 
+			if closed != 0 :
+				mailproc.log("Forum category is closed, not posting")
+				exit(0)
+
+
 			# Look up group name
 			mailproc.log("Looking up group informaiton on forum post for groupid " + str(groupid))
 			db = mailproc.db_connect()
 			cursor = db.cursor()
-			sql  = "SELECT xg.`description`, xg.`cn` FROM jos_xgroups xg WHERE xg.gidNumber = %s"
+			sql  = "SELECT xg.`description`, xg.`cn`, case when plugins like '%%forum=nobody%%' then 1 else 0 end as ForumClosed FROM jos_xgroups xg WHERE xg.gidNumber = %s"
 			data = (groupid)
 			cursor.execute(sql, data)
 			rs = cursor.fetchone()
@@ -230,10 +236,16 @@ try:
 			else:
 				groupDescription = rs[0]
 				groupName = rs[1]
+				groupForumClosed = rs[2]
 
 			cursor.close()
 			db.close()
 
+			if groupForumClosed != 0 :
+				mailproc.log("The group forum is closed, not posting")
+				exit(0)
+
+
 			# Do a database insert into the jos_xforum table. Need to support multiple versions of this table, specifically
 			# the scope and thread fields are not always present
 			db = mailproc.db_connect()
